@@ -195,7 +195,8 @@ class MainWindow(QMainWindow):
         # Topic tab signals
         self.topic_tab.topics_extracted.connect(self.on_topics_extracted)
         self.topic_tab.progress_updated.connect(self.update_progress)
-        
+
+
         # Validator tab signals
         self.validator_tab.validation_completed.connect(self.on_validation_completed)
         self.validator_tab.progress_updated.connect(self.update_progress)
@@ -230,7 +231,28 @@ class MainWindow(QMainWindow):
         
         # Switch to the topic tab
         self.tabs.setCurrentWidget(self.topic_tab)
-    
+        
+    def _on_topic_modeling_completed(self, topics, probs, topics_words, topic_info, model, documents):
+        """
+        Handle completion of topic modeling by passing results to other tabs.
+        """
+        # Update validator tab
+        self.validator_tab.set_topic_model_data(model, topics, topics_words, documents)
+        
+        # Update visualizer tab
+        self.visualizer_tab.set_topic_model_data(model, topics, topics_words, documents)
+        
+        # Update graph knowledge tab
+        self.graph_knowledge_tab.set_topic_model_data(
+            self.topic_tab.topic_modeler, documents, topics, topic_info, topics_words
+        )
+        
+        # Enable the graph knowledge tab after topic modeling
+        tab_index = self.tabs.indexOf(self.graph_knowledge_tab)
+        if tab_index >= 0:
+            self.tab_widget_status[tab_index] = True
+            self.update_tab_status()  
+              
     @pyqtSlot(object, object, object, object, object)
     def on_topics_extracted(self, topics, probs, topics_words, topic_info, chunked_docs):
         """Handle extracted topics"""
@@ -411,7 +433,8 @@ class MainWindow(QMainWindow):
                 topics_words = model.get_topics()
                 topic_info = model.get_topic_info()
                 
-                self.on_topics_extracted(topics, probs, topics_words, topic_info)
+                # Fix: Add chunked_docs parameter (use original documents)
+                self.on_topics_extracted(topics, probs, topics_words, topic_info, self.documents)
             
             QMessageBox.information(
                 self, "Load Complete", f"Topic model loaded from {file_path}"
@@ -420,8 +443,7 @@ class MainWindow(QMainWindow):
             logger.error(f"Error loading topic model: {str(e)}")
             QMessageBox.warning(
                 self, "Load Error", f"Failed to load topic model: {str(e)}"
-            )
-    
+            )    
     def show_settings_dialog(self):
         """Show the settings dialog for API configuration"""
         dialog = SettingsDialog(self)
@@ -443,4 +465,4 @@ class MainWindow(QMainWindow):
             "<li>Topic refinement with LLM APIs</li>"
             "<li>Topic validation and visualization</li>"
             "</ul>"
-        )
\ No newline at end of file
+        )
