@@ -664,6 +664,9 @@ class ProcessorTab(QWidget):
             <li><b>Optional stemming</b>: Reduces words to their root form by removing suffixes</li>
         </ul>
         
+        <p>When uploaidn one document. Remeber that the algroithms can consider text as different documents if there are serveral lines between text.
+        Remove these lines if you want the text to be considered as one document.</p>
+        
         <p>Well-processed text leads to more coherent topics, clearer patterns, and better insights
         during the topic modeling stage.</p>
         """)
