@@ -14,9 +14,10 @@ from PyQt5.QtWidgets import (QWidget, QVBoxLayout, QHBoxLayout, QPushButton,
                            QDialog, QRadioButton, QButtonGroup, QTabWidget,
                            QListWidget, QListWidgetItem, QStyle, QSizePolicy, 
                            QScrollArea, QFormLayout, QHeaderView)
-from PyQt5.QtCore import Qt, pyqtSignal, pyqtSlot
+from PyQt5.QtCore import Qt, pyqtSignal,QMimeData, pyqtSlot
 from PyQt5.QtGui import QIcon
-
+from PyQt5.QtGui import QKeySequence, QGuiApplication,QClipboard
+from PyQt5.QtWidgets import QAction, QApplication
 from ..core.topic_modeler import TopicModeler
 from ..core.llm_service import LLMService
 
@@ -484,6 +485,12 @@ class TopicTab(QWidget):
         self.topic_table.horizontalHeader().setSectionResizeMode(1, QHeaderView.ResizeToContents)  # Count
         self.topic_table.horizontalHeader().setSectionResizeMode(2, QHeaderView.Interactive)  # Words
         self.topic_table.horizontalHeader().setSectionResizeMode(3, QHeaderView.Stretch)  # Description
+        
+        copy_act = QAction("Copy", self)
+        copy_act.setShortcut(QKeySequence.Copy)
+        copy_act.triggered.connect(lambda _, tbl=self.topic_table: self._copy_from_table(tbl))
+        self.topic_table.addAction(copy_act)
+        self.topic_table.setContextMenuPolicy(Qt.ActionsContextMenu)
         self.topic_table.verticalHeader().setVisible(False)  # Hide vertical headers
         self.topic_table.setAlternatingRowColors(True)  # Alternate row colors for readability
         self.topic_table.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
@@ -503,6 +510,11 @@ class TopicTab(QWidget):
         self.doc_topic_table.horizontalHeader().setSectionResizeMode(0, QHeaderView.Stretch)  # Document
         self.doc_topic_table.horizontalHeader().setSectionResizeMode(1, QHeaderView.ResizeToContents)  # Topic ID
         self.doc_topic_table.horizontalHeader().setSectionResizeMode(2, QHeaderView.ResizeToContents)  # Probability
+        copy_act = QAction("Copy", self)
+        copy_act.setShortcut(QKeySequence.Copy)
+        copy_act.triggered.connect(lambda _, tbl=self.doc_topic_table: self._copy_from_table(tbl))
+        self.doc_topic_table.addAction(copy_act)
+        self.doc_topic_table.setContextMenuPolicy(Qt.ActionsContextMenu)        
         self.doc_topic_table.verticalHeader().setVisible(False)  # Hide vertical headers
         self.doc_topic_table.setAlternatingRowColors(True)  # Alternate row colors for readability
         self.doc_topic_table.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
@@ -534,6 +546,12 @@ class TopicTab(QWidget):
         self.keywords_table.horizontalHeader().setSectionResizeMode(0, QHeaderView.Stretch)  # Word
         self.keywords_table.horizontalHeader().setSectionResizeMode(1, QHeaderView.ResizeToContents)  # Score
         self.keywords_table.verticalHeader().setVisible(False)  # Hide vertical headers
+        copy_act = QAction("Copy", self)
+        copy_act.setShortcut(QKeySequence.Copy)
+        copy_act.triggered.connect(lambda _, tbl=self.keywords_table: self._copy_from_table(tbl))
+        self.keywords_table.addAction(copy_act)
+        self.keywords_table.setContextMenuPolicy(Qt.ActionsContextMenu)
+
         self.keywords_table.setAlternatingRowColors(True)  # Alternate row colors for readability
         self.keywords_table.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
         keywords_layout.addWidget(self.keywords_table)
@@ -548,7 +566,42 @@ class TopicTab(QWidget):
         
         # Connect signals and slots
         self.connect_signals()
-    
+
+
+
+    def _copy_from_table(self, table: QTableWidget):
+        """Copy selected cells as TSV (and HTML) to the system clipboard."""
+        selected = table.selectedIndexes()
+        if not selected:
+            return
+
+        # Build a 2D array of cell texts
+        # (accounting for possible non‑contiguous selections)
+        rows = {}
+        for idx in selected:
+            rows.setdefault(idx.row(), {})[idx.column()] = table.item(idx.row(), idx.column()).text()
+
+        # Create TSV plain‑text
+        tsv_lines = []
+        for row in sorted(rows):
+            cols = rows[row]
+            line = [ cols.get(col, "") for col in sorted(cols) ]
+            tsv_lines.append("\t".join(line))
+        plain = "\n".join(tsv_lines)
+
+        # (Optional) Build a simple HTML table for rich paste
+        html = "<table>\n"
+        for line in tsv_lines:
+            html += "  <tr>" + "".join(f"<td>{cell}</td>" for cell in line.split("\t")) + "</tr>\n"
+        html += "</table>"
+
+        # Put both on the clipboard
+        mime = QMimeData()
+        mime.setText(plain)    # plain‑text for external apps
+        mime.setHtml(html)     # HTML for rich‑paste targets
+        QApplication.clipboard().setMimeData(mime, mode=QClipboard.Clipboard)
+
+   
     def connect_signals(self):
         """Connect signals and slots"""
         # Connect to progress updates from the topic modeler
